/* SW_CRT_binary_power_designA_SAS_v4.sas
* date: June 14 2021;
* Authors' name: John Preisser & Ying Zhang;
* ref: "A general method for calculating power for GEE analysis of stepped wedge cluster randomized trials";
* what: compute GEE power for binary outcomes under Connect Home design based on the application section in the paper
  using thr fast GEE macro in swpoer_3_responses_v4.sas;                              
*/

/********Power for Design A in Connect Home trial from the PCORI, with 6 clusters and five correlation structures****************************************/
ods pdf file="G:/projects/swcrt/Incomplete_SWCRT_paper_code/paper_fastGEE_power-results/Incomplete_SWCRT_Table2_WebTable2.pdf";


%macro SW_CRT_sample_size(marginal_model, cluster_per_step, size , effect_size);
title "Design A : 6 clusters in 22 periods with 6 steps and &size cluster period size, binary outcomes  with the average intervention effect model and time effect parameters=(0.85,-0.01)";
title2 "Hussy and Hughes: (alpha1, alpha2)= (0.03,0.03)";

%CRTFASTGEEPWR(alpha=0.05, m =%str(J(6,1,&cluster_per_step)), corr_type = 1,alpha1 = 0.03,alpha2 = 0.03 ,
   intervention_effect_type=&marginal_model,max_intervention_period=10, delta = &effect_size, period_effect_type=2, beta_period_effects =%str({0.85,-0.01}) ,dist = "binary",phi=1,
   CP_size_matrix =      
						  %str({&size &size &size &size &size 0 0 &size &size &size &size &size &size &size &size &size &size 0 0 0 0 0,
					       		0 &size &size &size &size &size &size 0 0 &size &size &size &size &size &size &size &size &size 0 0 0 0,
					       		0 0 &size &size &size &size &size &size &size 0 0 &size &size &size &size &size &size &size &size 0 0 0,
					       		0 0 0 &size &size &size &size &size &size &size &size 0 0 &size &size &size &size &size &size &size 0 0,
					       		0 0 0 0 &size &size &size &size &size &size &size &size &size 0 0 &size &size &size &size &size &size 0,
								0 0 0 0 0 &size &size &size &size &size &size &size &size &size &size 0 0  &size &size &size &size &size}),
   DesignPattern =        %str({0 0 0 0 0 2 2 1 1 1 1 1 1 1 1 1 1 2 2 2 2 2,
					       		2 0 0 0 0 0 0 2 2 1 1 1 1 1 1 1 1 1 2 2 2 2,
					       		2 2 0 0 0 0 0 0 0 2 2 1 1 1 1 1 1 1 1 2 2 2,
					       		2 2 2 0 0 0 0 0 0 0 0 2 2 1 1 1 1 1 1 1 2 2,
					       		2 2 2 2 0 0 0 0 0 0 0 0 0 2 2 1 1 1 1 1 1 2,
					       		2 2 2 2 2 0 0 0 0 0 0 0 0 0 0 2 2 1 1 1 1 1}));
	

title2 "exponentional decay: assume (a0,r)=(0.03, 0.8) ";
%CRTFASTGEEPWR(alpha=0.05, m =%str(J(6,1,&cluster_per_step)), corr_type = 2,alpha0 = 0.03,r0 = 0.8 ,
   intervention_effect_type=&marginal_model,max_intervention_period=10, delta = &effect_size, period_effect_type=2, beta_period_effects =%str({0.85,-0.01})  ,dist = "binary",phi=1,
   CP_size_matrix =      
						  %str({&size &size &size &size &size 0 0 &size &size &size &size &size &size &size &size &size &size 0 0 0 0 0,
					       		0 &size &size &size &size &size &size 0 0 &size &size &size &size &size &size &size &size &size 0 0 0 0,
					       		0 0 &size &size &size &size &size &size &size 0 0 &size &size &size &size &size &size &size &size 0 0 0,
					       		0 0 0 &size &size &size &size &size &size &size &size 0 0 &size &size &size &size &size &size &size 0 0,
					       		0 0 0 0 &size &size &size &size &size &size &size &size &size 0 0 &size &size &size &size &size &size 0,
								0 0 0 0 0 &size &size &size &size &size &size &size &size &size &size 0 0  &size &size &size &size &size}),
   DesignPattern =        %str({0 0 0 0 0 2 2 1 1 1 1 1 1 1 1 1 1 2 2 2 2 2,
					       		2 0 0 0 0 0 0 2 2 1 1 1 1 1 1 1 1 1 2 2 2 2,
					       		2 2 0 0 0 0 0 0 0 2 2 1 1 1 1 1 1 1 1 2 2 2,
					       		2 2 2 0 0 0 0 0 0 0 0 2 2 1 1 1 1 1 1 1 2 2,
					       		2 2 2 2 0 0 0 0 0 0 0 0 0 2 2 1 1 1 1 1 1 2,
					       		2 2 2 2 2 0 0 0 0 0 0 0 0 0 0 2 2 1 1 1 1 1}));
	
            

title2 "Nested exchangeable: (alpha1,alpha2)= (0.03,0.015)";
%CRTFASTGEEPWR(alpha=0.05, m =%str(J(6,1,&cluster_per_step)), corr_type = 1,alpha1 = 0.03,alpha2 = 0.015 ,
   intervention_effect_type=&marginal_model,max_intervention_period=10, delta = &effect_size, period_effect_type=2, beta_period_effects =%str({0.85,-0.01})  ,dist = "binary",phi=1,
  CP_size_matrix =      
						  %str({&size &size &size &size &size 0 0 &size &size &size &size &size &size &size &size &size &size 0 0 0 0 0,
					       		0 &size &size &size &size &size &size 0 0 &size &size &size &size &size &size &size &size &size 0 0 0 0,
					       		0 0 &size &size &size &size &size &size &size 0 0 &size &size &size &size &size &size &size &size 0 0 0,
					       		0 0 0 &size &size &size &size &size &size &size &size 0 0 &size &size &size &size &size &size &size 0 0,
					       		0 0 0 0 &size &size &size &size &size &size &size &size &size 0 0 &size &size &size &size &size &size 0,
								0 0 0 0 0 &size &size &size &size &size &size &size &size &size &size 0 0  &size &size &size &size &size}),
					       		
   DesignPattern =        %str({0 0 0 0 0 2 2 1 1 1 1 1 1 1 1 1 1 2 2 2 2 2,
					       		2 0 0 0 0 0 0 2 2 1 1 1 1 1 1 1 1 1 2 2 2 2,
					       		2 2 0 0 0 0 0 0 0 2 2 1 1 1 1 1 1 1 1 2 2 2,
					       		2 2 2 0 0 0 0 0 0 0 0 2 2 1 1 1 1 1 1 1 2 2,
					       		2 2 2 2 0 0 0 0 0 0 0 0 0 2 2 1 1 1 1 1 1 2,
					       		2 2 2 2 2 0 0 0 0 0 0 0 0 0 0 2 2 1 1 1 1 1}));

           
 
title2 "Blocked exchangeable: (alpha1,alpha2)= (0.03,0.015,0.2)";
%CRTFASTGEEPWR(alpha=0.05, m =%str(J(6,1,&cluster_per_step)), corr_type = 3,alpha1 = 0.03,alpha2 = 0.015 ,alpha3 = 0.2 ,
   intervention_effect_type=&marginal_model,max_intervention_period=10, delta = &effect_size, period_effect_type=2, beta_period_effects =%str({0.85,-0.01})  ,dist = "binary",phi=1,
  CP_size_matrix =      
						  %str({&size &size &size &size &size 0 0 &size &size &size &size &size &size &size &size &size &size 0 0 0 0 0,
					       		0 &size &size &size &size &size &size 0 0 &size &size &size &size &size &size &size &size &size 0 0 0 0,
					       		0 0 &size &size &size &size &size &size &size 0 0 &size &size &size &size &size &size &size &size 0 0 0,
					       		0 0 0 &size &size &size &size &size &size &size &size 0 0 &size &size &size &size &size &size &size 0 0,
					       		0 0 0 0 &size &size &size &size &size &size &size &size &size 0 0 &size &size &size &size &size &size 0,
								0 0 0 0 0 &size &size &size &size &size &size &size &size &size &size 0 0  &size &size &size &size &size}),
					       		
   DesignPattern =        %str({0 0 0 0 0 2 2 1 1 1 1 1 1 1 1 1 1 2 2 2 2 2,
					       		2 0 0 0 0 0 0 2 2 1 1 1 1 1 1 1 1 1 2 2 2 2,
					       		2 2 0 0 0 0 0 0 0 2 2 1 1 1 1 1 1 1 1 2 2 2,
					       		2 2 2 0 0 0 0 0 0 0 0 2 2 1 1 1 1 1 1 1 2 2,
					       		2 2 2 2 0 0 0 0 0 0 0 0 0 2 2 1 1 1 1 1 1 2,
					       		2 2 2 2 2 0 0 0 0 0 0 0 0 0 0 2 2 1 1 1 1 1}));

 
title2 "Proportional decay: assume (a0,r)=(0.03, 0.7) ";
%CRTFASTGEEPWR(alpha=0.05, m =%str(J(6,1,&cluster_per_step)), corr_type = 4,alpha0 = 0.03,r0 = 0.7 ,
   intervention_effect_type=&marginal_model,max_intervention_period=10, delta = &effect_size, period_effect_type=2, beta_period_effects =%str({0.85,-0.01})  ,dist = "binary",phi=1,
   CP_size_matrix =      
						  %str({&size &size &size &size &size 0 0 &size &size &size &size &size &size &size &size &size &size 0 0 0 0 0,
					       		0 &size &size &size &size &size &size 0 0 &size &size &size &size &size &size &size &size &size 0 0 0 0,
					       		0 0 &size &size &size &size &size &size &size 0 0 &size &size &size &size &size &size &size &size 0 0 0,
					       		0 0 0 &size &size &size &size &size &size &size &size 0 0 &size &size &size &size &size &size &size 0 0,
					       		0 0 0 0 &size &size &size &size &size &size &size &size &size 0 0 &size &size &size &size &size &size 0,
								0 0 0 0 0 &size &size &size &size &size &size &size &size &size &size 0 0  &size &size &size &size &size}),
   DesignPattern =        %str({0 0 0 0 0 2 2 1 1 1 1 1 1 1 1 1 1 2 2 2 2 2,
					       		2 0 0 0 0 0 0 2 2 1 1 1 1 1 1 1 1 1 2 2 2 2,
					       		2 2 0 0 0 0 0 0 0 2 2 1 1 1 1 1 1 1 1 2 2 2,
					       		2 2 2 0 0 0 0 0 0 0 0 2 2 1 1 1 1 1 1 1 2 2,
					       		2 2 2 2 0 0 0 0 0 0 0 0 0 2 2 1 1 1 1 1 1 2,
					       		2 2 2 2 2 0 0 0 0 0 0 0 0 0 0 2 2 1 1 1 1 1}));
	

%mend;


title "Design A : 6 clusters in 22 periods with 6 steps, binary outcomes  with the average intervention effect model(-1.2) and time effect parameters=(0.85,-0.01)";
%SW_CRT_sample_size(1,  1,  4 , -1.2);
%SW_CRT_sample_size(1,  1,  4 , -1.4);

title "Design A : 12 clusters in 22 periods with 6 steps, binary outcomes  with the average intervention effect model(-1.2) and time effect parameters=(0.85,-0.01)";
%SW_CRT_sample_size(1,  2,  2 , -1.2);
%SW_CRT_sample_size(1,  2,  2 , -1.4);


title "Design A : 6 clusters in 22 periods with 6 steps, binary outcomes  with the incremental intervention effect model(-1.2) and time effect parameters=(0.85,-0.01)";
%SW_CRT_sample_size(2, 1,   4 , -1.8);
%SW_CRT_sample_size(2, 1,   4 , -2.4);

title "Design A : 12 clusters in 22 periods with 6 steps, binary outcomes  with the incremental intervention effect model(-1.2) and time effect parameters=(0.85,-0.01)";
%SW_CRT_sample_size(2, 2,   2 , -1.8);
%SW_CRT_sample_size(2, 2,   2 , -2.4);

ods pdf close;
