/* SW_CRT_binary_sample_size_SAS_v4.sas
* date: June 13 2021;
* Authors' name: John Preisser & Ying Zhang;
* ref: "A general method for calculating power for GEE analysis of stepped wedge cluster randomized trials";
* what: compute GEE power for binary outcomes under Connect Home design based on the application section in the paper
  using thr fast GEE macro in swpoer_3_responses_v4.sas;                              
*/

/********Power for Design A in Connect Home trial from the PCORI, with 6 clusters and three correlation structures****************************************/
ods pdf file="G:/projects/swcrt/Incomplete_SWCRT_paper_code/paper_fastGEE_power-results/Incomplete_SWCRT_Table4.pdf";


%macro SW_CRT_sample_size(marginal_model,  size , effect_size);
title "Design A : 6 clusters in 22 periods with 6 steps and &size cluster period size, binary outcomes  with the average intervention effect model and time effect parameters=(0.85,-0.01)";
title2 "Hussy and Hughes: (alpha1, alpha2)= (0.03,0.03)";

%CRTFASTGEEPWR(alpha=0.05, m =%str(J(6,1,1)), corr_type = 1,alpha1 = 0.03,alpha2 = 0.03 ,
   intervention_effect_type=&marginal_model,max_intervention_period=10, delta = &effect_size, period_effect_type=2, beta_period_effects =%str({0.85,-0.01})  ,dist = "binary",phi=1,
   CP_size_matrix =      
						  %str({&size &size &size &size &size 0 0 &size &size &size &size &size &size &size &size &size &size 0 0 0 0 0,
					       		0 &size &size &size &size &size &size 0 0 &size &size &size &size &size &size &size &size &size 0 0 0 0,
					       		0 0 &size &size &size &size &size &size &size 0 0 &size &size &size &size &size &size &size &size 0 0 0,
					       		0 0 0 &size &size &size &size &size &size &size &size 0 0 &size &size &size &size &size &size &size 0 0,
					       		0 0 0 0 &size &size &size &size &size &size &size &size &size 0 0 &size &size &size &size &size &size 0,
								0 0 0 0 0 &size &size &size &size &size &size &size &size &size &size 0 0  &size &size &size &size &size}),
   DesignPattern =        %str({0 0 0 0 0 2 2 1 1 1 1 1 1 1 1 1 1 2 2 2 2 2,
					       		2 0 0 0 0 0 0 2 2 1 1 1 1 1 1 1 1 1 2 2 2 2,
					       		2 2 0 0 0 0 0 0 0 2 2 1 1 1 1 1 1 1 1 2 2 2,
					       		2 2 2 0 0 0 0 0 0 0 0 2 2 1 1 1 1 1 1 1 2 2,
					       		2 2 2 2 0 0 0 0 0 0 0 0 0 2 2 1 1 1 1 1 1 2,
					       		2 2 2 2 2 0 0 0 0 0 0 0 0 0 0 2 2 1 1 1 1 1}));
	

title2 "exponentional decay: assume (a0,r)=(0.03, 0.8) ";
%CRTFASTGEEPWR(alpha=0.05, m =%str(J(6,1,1)), corr_type = 2,alpha0 = 0.03,r0 = 0.8 ,
   intervention_effect_type=&marginal_model,max_intervention_period=10, delta = &effect_size, period_effect_type=2, beta_period_effects =%str({0.85,-0.01})  ,dist = "binary",phi=1,
   CP_size_matrix =      
						  %str({&size &size &size &size &size 0 0 &size &size &size &size &size &size &size &size &size &size 0 0 0 0 0,
					       		0 &size &size &size &size &size &size 0 0 &size &size &size &size &size &size &size &size &size 0 0 0 0,
					       		0 0 &size &size &size &size &size &size &size 0 0 &size &size &size &size &size &size &size &size 0 0 0,
					       		0 0 0 &size &size &size &size &size &size &size &size 0 0 &size &size &size &size &size &size &size 0 0,
					       		0 0 0 0 &size &size &size &size &size &size &size &size &size 0 0 &size &size &size &size &size &size 0,
								0 0 0 0 0 &size &size &size &size &size &size &size &size &size &size 0 0  &size &size &size &size &size}),
   DesignPattern =        %str({0 0 0 0 0 2 2 1 1 1 1 1 1 1 1 1 1 2 2 2 2 2,
					       		2 0 0 0 0 0 0 2 2 1 1 1 1 1 1 1 1 1 2 2 2 2,
					       		2 2 0 0 0 0 0 0 0 2 2 1 1 1 1 1 1 1 1 2 2 2,
					       		2 2 2 0 0 0 0 0 0 0 0 2 2 1 1 1 1 1 1 1 2 2,
					       		2 2 2 2 0 0 0 0 0 0 0 0 0 2 2 1 1 1 1 1 1 2,
					       		2 2 2 2 2 0 0 0 0 0 0 0 0 0 0 2 2 1 1 1 1 1}));
	
            
 
title2 "Nested exchangeable: (alpha1,alpha2)= (0.03,0.015)";
%CRTFASTGEEPWR(alpha=0.05, m =%str(J(6,1,1)), corr_type = 1,alpha1 = 0.03,alpha2 = 0.015 ,
   intervention_effect_type=&marginal_model,max_intervention_period=10, delta = &effect_size, period_effect_type=2, beta_period_effects =%str({0.85,-0.01})  ,dist = "binary",phi=1,
  CP_size_matrix =      
						  %str({&size &size &size &size &size 0 0 &size &size &size &size &size &size &size &size &size &size 0 0 0 0 0,
					       		0 &size &size &size &size &size &size 0 0 &size &size &size &size &size &size &size &size &size 0 0 0 0,
					       		0 0 &size &size &size &size &size &size &size 0 0 &size &size &size &size &size &size &size &size 0 0 0,
					       		0 0 0 &size &size &size &size &size &size &size &size 0 0 &size &size &size &size &size &size &size 0 0,
					       		0 0 0 0 &size &size &size &size &size &size &size &size &size 0 0 &size &size &size &size &size &size 0,
								0 0 0 0 0 &size &size &size &size &size &size &size &size &size &size 0 0  &size &size &size &size &size}),
					       		
   DesignPattern =        %str({0 0 0 0 0 2 2 1 1 1 1 1 1 1 1 1 1 2 2 2 2 2,
					       		2 0 0 0 0 0 0 2 2 1 1 1 1 1 1 1 1 1 2 2 2 2,
					       		2 2 0 0 0 0 0 0 0 2 2 1 1 1 1 1 1 1 1 2 2 2,
					       		2 2 2 0 0 0 0 0 0 0 0 2 2 1 1 1 1 1 1 1 2 2,
					       		2 2 2 2 0 0 0 0 0 0 0 0 0 2 2 1 1 1 1 1 1 2,
					       		2 2 2 2 2 0 0 0 0 0 0 0 0 0 0 2 2 1 1 1 1 1}));
%mend;


title "Design A : 6 clusters in 22 periods with 6 steps, binary outcomes  with the average intervention effect model(-1.2) and time effect parameters=(0.85,-0.01)";
%SW_CRT_sample_size(1,  4 , -1.2);
%SW_CRT_sample_size(1,  5 , -1.2);
%SW_CRT_sample_size(1,  6 , -1.2);
%SW_CRT_sample_size(1,  7 , -1.2);
%SW_CRT_sample_size(1,  8 , -1.2);
%SW_CRT_sample_size(1,  9 , -1.2);

title "Design A : 6 clusters in 22 periods with 6 steps, binary outcomes  with the average intervention effect model(-1.4) and time effect parameters=(0.85,-0.01)";
%SW_CRT_sample_size(1,  4 , -1.4);
%SW_CRT_sample_size(1,  5 , -1.4);
%SW_CRT_sample_size(1,  6 , -1.4);
%SW_CRT_sample_size(1,  7 , -1.4);
%SW_CRT_sample_size(1,  8 , -1.4);
%SW_CRT_sample_size(1,  9 , -1.4);

title "Design A : 6 clusters in 22 periods with 6 steps, binary outcomes  with the incremental intervention effect model(-1.8) and time effect parameters=(0.85,-0.01)";
%SW_CRT_sample_size(2,  4 , -1.8);
%SW_CRT_sample_size(2,  5 , -1.8);
%SW_CRT_sample_size(2,  6 , -1.8);
%SW_CRT_sample_size(2,  7 , -1.8);
%SW_CRT_sample_size(2,  8 , -1.8);
%SW_CRT_sample_size(2,  9 , -1.8);

title "Design A : 6 clusters in 22 periods with 6 steps, binary outcomes  with the incremental intervention effect model(-2.4) and time effect parameters=(0.85,-0.01)";
%SW_CRT_sample_size(2,  4 , -2.4);
%SW_CRT_sample_size(2,  5 , -2.4);
%SW_CRT_sample_size(2,  6 , -2.4);
%SW_CRT_sample_size(2,  7 , -2.4);
%SW_CRT_sample_size(2,  8 , -2.4);
%SW_CRT_sample_size(2,  9 , -2.4);

ods pdf close;
