/* SW_CRT_normal_sample_size_SAS_v4.sas
* date: June 13 2021;
* Authors' name: John Preisser & Ying Zhang;
* ref: "A general method for calculating power for GEE analysis of stepped wedge cluster randomized trials";
* what: compute GEE power for normal outcomes under Connect Home design based on the application section in the paper
  using thr fast GEE macro in swpoer_3_responses_v4.sas;                              
*/

/********Power for Design A in Connect Home trial from the PCORI, with 6 clusters and five correlation structures****************************************/

ods pdf file="G:/projects/swcrt/Incomplete_SWCRT_paper_code/paper_fastGEE_power-results/Incomplete_SWCRT_WebTable8.pdf" ;

%macro SW_CRT_sample_size(marginal_model,  size , effect_size);
title "Design A : 6 clusters in 22 periods with 6 steps and &size cluster period size, normal outcomes  with the average intervention effect model and time effect parameters=(2,-0.05)";
title2 "Hussy and Hughes: (alpha1, alpha2)= (0.03,0.03)";

%CRTFASTGEEPWR(alpha=0.05, m =%str(J(6,1,1)), corr_type = 1,alpha1 = 0.03,alpha2 = 0.03 ,
   intervention_effect_type=&marginal_model,max_intervention_period=10, delta = &effect_size, period_effect_type=2, beta_period_effects =%str({2,-0.05})  ,dist = "normal",phi=1,
   CP_size_matrix =      
						  %str({&size &size &size &size &size 0 0 &size &size &size &size &size &size &size &size &size &size 0 0 0 0 0,
					       		0 &size &size &size &size &size &size 0 0 &size &size &size &size &size &size &size &size &size 0 0 0 0,
					       		0 0 &size &size &size &size &size &size &size 0 0 &size &size &size &size &size &size &size &size 0 0 0,
					       		0 0 0 &size &size &size &size &size &size &size &size 0 0 &size &size &size &size &size &size &size 0 0,
					       		0 0 0 0 &size &size &size &size &size &size &size &size &size 0 0 &size &size &size &size &size &size 0,
								0 0 0 0 0 &size &size &size &size &size &size &size &size &size &size 0 0  &size &size &size &size &size}),
   DesignPattern =        %str({0 0 0 0 0 2 2 1 1 1 1 1 1 1 1 1 1 2 2 2 2 2,
					       		2 0 0 0 0 0 0 2 2 1 1 1 1 1 1 1 1 1 2 2 2 2,
					       		2 2 0 0 0 0 0 0 0 2 2 1 1 1 1 1 1 1 1 2 2 2,
					       		2 2 2 0 0 0 0 0 0 0 0 2 2 1 1 1 1 1 1 1 2 2,
					       		2 2 2 2 0 0 0 0 0 0 0 0 0 2 2 1 1 1 1 1 1 2,
					       		2 2 2 2 2 0 0 0 0 0 0 0 0 0 0 2 2 1 1 1 1 1}));
	

title2 "exponentional decay: assume (a0,r)=(0.03, 0.8) ";
%CRTFASTGEEPWR(alpha=0.05, m =%str(J(6,1,1)), corr_type = 2,alpha0 = 0.03,r0 = 0.8 ,
   intervention_effect_type=&marginal_model,max_intervention_period=10, delta = &effect_size, period_effect_type=2, beta_period_effects =%str({2,-0.05})  ,dist = "normal",phi=1,
   CP_size_matrix =      
						  %str({&size &size &size &size &size 0 0 &size &size &size &size &size &size &size &size &size &size 0 0 0 0 0,
					       		0 &size &size &size &size &size &size 0 0 &size &size &size &size &size &size &size &size &size 0 0 0 0,
					       		0 0 &size &size &size &size &size &size &size 0 0 &size &size &size &size &size &size &size &size 0 0 0,
					       		0 0 0 &size &size &size &size &size &size &size &size 0 0 &size &size &size &size &size &size &size 0 0,
					       		0 0 0 0 &size &size &size &size &size &size &size &size &size 0 0 &size &size &size &size &size &size 0,
								0 0 0 0 0 &size &size &size &size &size &size &size &size &size &size 0 0  &size &size &size &size &size}),
   DesignPattern =        %str({0 0 0 0 0 2 2 1 1 1 1 1 1 1 1 1 1 2 2 2 2 2,
					       		2 0 0 0 0 0 0 2 2 1 1 1 1 1 1 1 1 1 2 2 2 2,
					       		2 2 0 0 0 0 0 0 0 2 2 1 1 1 1 1 1 1 1 2 2 2,
					       		2 2 2 0 0 0 0 0 0 0 0 2 2 1 1 1 1 1 1 1 2 2,
					       		2 2 2 2 0 0 0 0 0 0 0 0 0 2 2 1 1 1 1 1 1 2,
					       		2 2 2 2 2 0 0 0 0 0 0 0 0 0 0 2 2 1 1 1 1 1}));
	
            
 
title2 "Nested exchangeable: (alpha1,alpha2)= (0.03,0.015)";
%CRTFASTGEEPWR(alpha=0.05, m =%str(J(6,1,1)), corr_type = 1,alpha1 = 0.03,alpha2 = 0.015 ,
   intervention_effect_type=&marginal_model,max_intervention_period=10, delta = &effect_size, period_effect_type=2, beta_period_effects =%str({2,-0.05})  ,dist = "normal",phi=1,
  CP_size_matrix =      
						  %str({&size &size &size &size &size 0 0 &size &size &size &size &size &size &size &size &size &size 0 0 0 0 0,
					       		0 &size &size &size &size &size &size 0 0 &size &size &size &size &size &size &size &size &size 0 0 0 0,
					       		0 0 &size &size &size &size &size &size &size 0 0 &size &size &size &size &size &size &size &size 0 0 0,
					       		0 0 0 &size &size &size &size &size &size &size &size 0 0 &size &size &size &size &size &size &size 0 0,
					       		0 0 0 0 &size &size &size &size &size &size &size &size &size 0 0 &size &size &size &size &size &size 0,
								0 0 0 0 0 &size &size &size &size &size &size &size &size &size &size 0 0  &size &size &size &size &size}),
					       		
   DesignPattern =        %str({0 0 0 0 0 2 2 1 1 1 1 1 1 1 1 1 1 2 2 2 2 2,
					       		2 0 0 0 0 0 0 2 2 1 1 1 1 1 1 1 1 1 2 2 2 2,
					       		2 2 0 0 0 0 0 0 0 2 2 1 1 1 1 1 1 1 1 2 2 2,
					       		2 2 2 0 0 0 0 0 0 0 0 2 2 1 1 1 1 1 1 1 2 2,
					       		2 2 2 2 0 0 0 0 0 0 0 0 0 2 2 1 1 1 1 1 1 2,
					       		2 2 2 2 2 0 0 0 0 0 0 0 0 0 0 2 2 1 1 1 1 1}));
%mend;


title "Design A : 6 clusters in 22 periods with 6 steps, normal outcomes  with the average intervention effect model(0.5) and time effect parameters=(2,-0.05)";
%SW_CRT_sample_size(1,  4 , 0.5);
%SW_CRT_sample_size(1,  5 , 0.5);
%SW_CRT_sample_size(1,  6 , 0.5);
%SW_CRT_sample_size(1,  7 , 0.5);
%SW_CRT_sample_size(1,  8 , 0.5);
%SW_CRT_sample_size(1,  9 , 0.5);

title "Design A : 6 clusters in 22 periods with 6 steps, normal outcomes  with the average intervention effect model(0.7) and time effect parameters=(2,-0.05)";
%SW_CRT_sample_size(1,  4 , 0.7);
%SW_CRT_sample_size(1,  5 , 0.7);
%SW_CRT_sample_size(1,  6 , 0.7);
%SW_CRT_sample_size(1,  7 , 0.7);
%SW_CRT_sample_size(1,  8 , 0.7);
%SW_CRT_sample_size(1,  9 , 0.7);

title "Design A : 6 clusters in 22 periods with 6 steps, normal outcomes  with the average intervention effect model(0.8) and time effect parameters=(2,-0.05)";
%SW_CRT_sample_size(2,  4 , 0.8);
%SW_CRT_sample_size(2,  5 , 0.8);
%SW_CRT_sample_size(2,  6 , 0.8);
%SW_CRT_sample_size(2,  7 , 0.8);
%SW_CRT_sample_size(2,  8 , 0.8);
%SW_CRT_sample_size(2,  9 , 0.8);

title "Design A : 6 clusters in 22 periods with 6 steps, normal outcomes  with the average intervention effect model(1.0) and time effect parameters=(2,-0.05)";
%SW_CRT_sample_size(2,  4 , 1.0);
%SW_CRT_sample_size(2,  5 , 1.0);
%SW_CRT_sample_size(2,  6 , 1.0);
%SW_CRT_sample_size(2,  7 , 1.0);
%SW_CRT_sample_size(2,  8 , 1.0);
%SW_CRT_sample_size(2,  9 , 1.0);

ods pdf close;
